% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/JAGS-formula.R
\name{JAGS_formula}
\alias{JAGS_formula}
\title{Create JAGS formula syntax and data object}
\usage{
JAGS_formula(formula, parameter, data, prior_list)
}
\arguments{
\item{formula}{formula specifying the right hand side of the assignment (the
left hand side is ignored)}

\item{parameter}{name of the parameter to be created with the formula}

\item{data}{data.frame containing predictors included in the formula}

\item{prior_list}{named list of prior distribution of parameters specified within
the \code{formula}}
}
\value{
\code{JAGS_formula} returns a list containing the formula JAGS syntax,
JAGS data object, and modified prior_list.
}
\description{
Creates a JAGS formula syntax, prepares data input, and
returns modified prior list for further processing in the \code{JAGS_fit}
function
}
\examples{
# simulate data
set.seed(1)
df <- data.frame(
  y      = rnorm(60),
  x_cont = rnorm(60),
  x_bin  = rbinom(60, 1, .5),
  x_fac3 = factor(rep(c("A", "B", "C"), 20), levels = c("A", "B", "C")),
  x_fac4 = factor(rep(c("A", "B", "C", "D"), 15), levels = c("A", "B", "C", "D"))
)

# specify priors
prior_list <- list(
"intercept"     = prior("normal", list(0, 1)),
"x_cont"        = prior("normal", list(0, .5)),
"x_fac3"        = prior_factor("normal",  list(0, 1),  contrast = "treatment"),
"x_fac4"        = prior_factor("mnormal", list(0, 1),  contrast = "orthonormal"),
"x_fac3:x_fac4" = prior_factor("mnormal", list(0, .5), contrast = "orthonormal")
)

# create the formula object
formula <- JAGS_formula(
  formula = ~ x_cont + x_fac3 * x_fac4,
  parameter = "mu", data = df, prior_list = prior_list)

}
\seealso{
\code{\link[=JAGS_fit]{JAGS_fit()}}
}
